Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4568)

Unified Diff: chrome/android/java/src/org/chromium/chrome/browser/payments/ui/SectionInformation.java

Issue 2059073002: Add "Checking" spinner for server-side shipping address validation. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Use existing color Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/android/java/src/org/chromium/chrome/browser/payments/ui/SectionInformation.java
diff --git a/chrome/android/java/src/org/chromium/chrome/browser/payments/ui/SectionInformation.java b/chrome/android/java/src/org/chromium/chrome/browser/payments/ui/SectionInformation.java
index 4003655b10977cd6bc5eafdab1beb92e4b1b8713..3f7cb046026729bdd1d70df12877d62bf4d6da8d 100644
--- a/chrome/android/java/src/org/chromium/chrome/browser/payments/ui/SectionInformation.java
+++ b/chrome/android/java/src/org/chromium/chrome/browser/payments/ui/SectionInformation.java
@@ -22,6 +22,11 @@ public class SectionInformation {
*/
public static final int NO_SELECTION = -1;
+ /**
+ * This value indicates that user selection is invalid in this section.
+ */
+ public static final int INVALID_SELECTION = -2;
+
@PaymentRequestUI.DataType private final int mDataType;
private final ArrayList<PaymentOption> mItems;
private int mSelectedItem;
@@ -100,8 +105,8 @@ public class SectionInformation {
/**
* Sets the currently selected item by index.
*
* @param index The index of the currently selected item, or NO_SELECTION if a selection has not
* yet been made.
*/
public void setSelectedItemIndex(int index) {
mSelectedItem = index;
@@ -126,8 +131,8 @@ public class SectionInformation {
/**
* Returns the index of the selected item.
*
* @return The index of the currently selected item, or NO_SELECTION if a selection has not yet
* been made.
*/
public int getSelectedItemIndex() {
return mSelectedItem;
@@ -100,8 +105,8 @@ public class SectionInformation {
* Sets the currently selected item by index.
*
- * @param index The index of the currently selected item, or NO_SELECTION if a selection has not
- * yet been made.
+ * @param index The index of the currently selected item, NO_SELECTION if a selection has not
+ * yet been made, or INVALID_SELECTION if an invalid selection has been made.
*/
public void setSelectedItemIndex(int index) {
@@ -126,8 +131,8 @@ public class SectionInformation {
* Returns the index of the selected item.
*
- * @return The index of the currently selected item, or NO_SELECTION if a selection has not yet
- * been made.
+ * @return The index of the currently selected item, NO_SELECTION if a selection has not yet
+ * been made, or INVALID_SELECTION if an invalid selection has been made.
*/
public int getSelectedItemIndex() {

Powered by Google App Engine
This is Rietveld 408576698